@@ -14,7 +14,7 @@ pip install -e ./tools
 [ -d privates ] && pip install -qqq privates/*.whl
 pip install $ALL_MODULES
 
-pip install "sphinx==1.6.7" -q
+pip install sphinx==1.6.7 Jinja2==3.0.3
 echo "Installed."
 
 cd doc/sphinx; python ./__main__.py
@@ -22,4 +22,3 @@ cd doc/sphinx; python ./__main__.py
 python $wd/test_help_doc_arguments.py "./_build/xml/ind.xml"
 
 echo "OK."
-
