@@ -4,7 +4,6 @@
 # --------------------------------------------------------------------------------------------
 
 import os
-import sys
 
 from azure.cli.core.util import CLIError
 from azure.cli.testsdk import ScenarioTest, ResourceGroupPreparer, StorageAccountPreparer
@@ -383,8 +382,6 @@ class AmsStreamingEndpointsTests(ScenarioTest):
     @ResourceGroupPreparer()
     @StorageAccountPreparer(parameter_name='storage_account_for_create')
     def test_ams_streaming_endpoint_stop_async(self, storage_account_for_create):
-        if sys.version_info.major == 2:  # azure-cli/issues/9386
-            return
         amsname = self.create_random_name(prefix='ams', length=12)
         streaming_endpoint_name = self.create_random_name(prefix="strep", length=12)
 
