@@ -12,9 +12,12 @@ from azure.cli.testsdk import (ResourceGroupPreparer, ScenarioTest)
 from azure.cli.testsdk.scenario_tests import AllowLargeResponse
 from azure.core.exceptions import ResourceNotFoundError, HttpResponseError
 from azure.cli.command_modules.appconfig.tests.latest._test_utils import CredentialResponseSanitizer, get_resource_name_prefix
+from azure.cli.core.azclierror import InvalidArgumentValueError
 
 TEST_DIR = os.path.abspath(os.path.join(os.path.abspath(__file__), '..'))
 
+
+
 class AppConfigMgmtScenarioTest(ScenarioTest):
 
     def __init__(self, *args, **kwargs):
@@ -441,6 +444,68 @@ class AppConfigMgmtScenarioTest(ScenarioTest):
                          self.check('sku.name', sku),
                          self.check('publicNetworkAccess', 'Enabled')])
 
+
+    @ResourceGroupPreparer(parameter_name_for_location='location')
+    @AllowLargeResponse()
+    def test_appconfig_kv_revision_retention_period(self, resource_group, location):
+        """Test kv_revision_retention_period for different SKUs and validation scenarios."""
+        mgmt_prefix = get_resource_name_prefix('RevisionRetention')
+        
+        # Test store names
+        standard_store_name = self.create_random_name(prefix=mgmt_prefix, length=24)
+        test_validation_store = self.create_random_name(prefix=mgmt_prefix, length=24)
+        
+        # SKUs and retention period in seconds
+        standard_sku = 'standard'
+        dev_sku = 'developer'
+        free_sku = 'free'
+        
+        standard_retention_period = 2592000  # Max for standard/premium
+        dev_retention_period = 604800         # Max for developer
+
+        self.kwargs.update({
+            'store_name': standard_store_name,
+            'test_store': test_validation_store,
+            'location': location,
+            'rg': resource_group,
+            'standard_sku': standard_sku,
+            'dev_sku': dev_sku,
+            'free_sku': free_sku
+        })
+        
+        # Create standard store with kv_revision_retention_period and verify
+        self.kwargs.update({
+            'retention_period': standard_retention_period
+        })
+        self.cmd('appconfig create -n {store_name} -g {rg} -l {location} --sku {standard_sku} --kv-revision-retention-period {retention_period}',
+                 checks=[self.check('name', '{store_name}'),
+                         self.check('sku.name', standard_sku),
+                         self.check('defaultKeyValueRevisionRetentionPeriodInSeconds', standard_retention_period)])
+
+        # Update retention period
+        updated_retention_period = 3600
+        self.kwargs['retention_period'] = updated_retention_period
+        self.cmd('appconfig update -n {store_name} -g {rg} --kv-revision-retention-period {retention_period}',
+                 checks=[self.check('name', '{store_name}'),
+                         self.check('defaultKeyValueRevisionRetentionPeriodInSeconds', updated_retention_period)])
+
+        # Validation scenarios - test invalid values
+        # Negative value
+        with self.assertRaisesRegex(InvalidArgumentValueError, 'The key value revision retention period cannot be negative'):
+            self.kwargs['retention_period'] = -1
+            self.cmd('appconfig create -n {test_store} -g {rg} -l {location} --sku {standard_sku} --kv-revision-retention-period {retention_period}')
+
+        # Test with developer SKU
+        self.kwargs.update({
+            'sku': dev_sku,
+            'retention_period': dev_retention_period,
+            'store_name': self.create_random_name(prefix=mgmt_prefix, length=24)
+        })
+        self.cmd('appconfig create -n {store_name} -g {rg} -l {location} --sku {sku} --kv-revision-retention-period {retention_period}',
+                 checks=[self.check('sku.name', dev_sku),
+                         self.check('defaultKeyValueRevisionRetentionPeriodInSeconds', dev_retention_period)])
+                        
+
 def _setup_key_vault(test, kwargs):
     key_vault = test.cmd('keyvault create -n {keyvault_name} -g {rg} -l {rg_loc} --enable-rbac-authorization false --enable-purge-protection --retention-days 7').get_output_in_json()
     test.cmd('keyvault key create --vault-name {keyvault_name} -n {encryption_key}')
