@@ -13,13 +13,8 @@ def ex_handler_factory(creating_plan=False, no_throw=False):
             detail = json.loads(ex.response.text)['Message']
             if creating_plan:
                 if 'Requested features are not supported in region' in detail:
-                    detail = ("Plan with linux worker is not supported in current region. For " +
-                              "supported regions, please refer to https://docs.microsoft.com/"
-                              "azure/app-service-web/app-service-linux-intro")
-                elif 'Not enough available reserved instance servers to satisfy' in detail:
-                    detail = ("Plan with Linux worker can only be created in a group " +
-                              "which has never contained a Windows worker, and vice versa. " +
-                              "Please use a new resource group. Original error:" + detail)
+                    detail = ("Selected plan is not supported in current region. " +
+                              "Original error: " + detail)
             ex = CLIError(detail)
         except Exception:  # pylint: disable=broad-except
             pass
