@@ -11,9 +11,12 @@ from knack.util import CLIError
 from azure.cli.command_modules.appservice.custom import (
     enable_zip_deploy_functionapp,
     enable_zip_deploy,
+    enable_zip_deploy_flex,
     add_remote_build_app_settings,
     remove_remote_build_app_settings,
-    validate_app_settings_in_scm)
+    config_source_control,
+    validate_app_settings_in_scm,
+    update_container_settings_functionapp)
 from azure.cli.core.profiles import ResourceType
 from azure.cli.core.azclierror import (AzureInternalError, UnclassifiedUserFault)
 
@@ -44,17 +47,32 @@ def _get_zip_deploy_headers(username, password, cmd_mock_client):
     return headers
 
 
+def _get_flex_zip_deploy_headers(cmd_mock_client):
+    from urllib3.util import make_headers
+    from azure.cli.core.util import get_az_user_agent
+
+    headers = make_headers()
+    headers['Authorization'] = "Bearer 1234"
+    headers['Content-Type'] = 'application/zip'
+    headers['Cache-Control'] = 'no-cache'
+    headers['User-Agent'] = get_az_user_agent()
+    headers['x-ms-client-request-id'] = cmd_mock_client.data['headers']['x-ms-client-request-id']
+    return headers
+
+
 class TestFunctionappMocked(unittest.TestCase):
     def setUp(self):
         self.client = WebSiteManagementClient(mock.MagicMock(), '123455678')
 
     @mock.patch('azure.cli.command_modules.appservice.custom.web_client_factory', autospec=True)
     @mock.patch('azure.cli.command_modules.appservice.custom.parse_resource_id')
+    @mock.patch('azure.cli.command_modules.appservice.custom.is_flex_functionapp', return_value=False)
     @mock.patch('azure.cli.command_modules.appservice.custom.enable_zip_deploy')
     @mock.patch('azure.cli.command_modules.appservice.custom.add_remote_build_app_settings')
     def test_functionapp_zip_deploy_flow(self,
                                          add_remote_build_app_settings_mock,
                                          enable_zip_deploy_mock,
+                                         is_flex_functionapp_mock,
                                          parse_resource_id_mock,
                                          web_client_factory_mock):
         cmd_mock = _get_test_cmd()
@@ -71,11 +89,13 @@ class TestFunctionappMocked(unittest.TestCase):
 
     @mock.patch('azure.cli.command_modules.appservice.custom.web_client_factory', autospec=True)
     @mock.patch('azure.cli.command_modules.appservice.custom.parse_resource_id')
+    @mock.patch('azure.cli.command_modules.appservice.custom.is_flex_functionapp', return_value=False)
     @mock.patch('azure.cli.command_modules.appservice.custom.enable_zip_deploy')
     @mock.patch('azure.cli.command_modules.appservice.custom.remove_remote_build_app_settings')
     def test_functionapp_zip_deploy_flow(self,
                                          remove_remote_build_app_settings_mock,
                                          enable_zip_deploy_mock,
+                                         is_flex_functionapp_mock,
                                          parse_resource_id_mock,
                                          web_client_factory_mock):
         cmd_mock = _get_test_cmd()
@@ -90,17 +110,21 @@ class TestFunctionappMocked(unittest.TestCase):
         enable_zip_deploy_mock.assert_called_once()
         remove_remote_build_app_settings_mock.assert_called_once()
 
+    @mock.patch('azure.cli.command_modules.appservice.custom.check_language_runtime')
     @mock.patch('azure.cli.command_modules.appservice.custom.web_client_factory', autospec=True)
     @mock.patch('azure.cli.command_modules.appservice.custom.parse_resource_id')
     @mock.patch('azure.cli.command_modules.appservice.custom.validate_zip_deploy_app_setting_exists')
     @mock.patch('azure.cli.command_modules.appservice.custom.upload_zip_to_storage')
     @mock.patch('azure.cli.command_modules.appservice.custom.is_plan_consumption', return_value=True)
+    @mock.patch('azure.cli.command_modules.appservice.custom.is_flex_functionapp', return_value=False)
     def test_functionapp_linux_consumption_non_remote_build(self,
+                                                            is_flex_functionapp_mock,
                                                             is_plan_consumption_mock,
                                                             upload_zip_to_storage_mock,
                                                             validate_zip_deploy_app_setting_exists_mock,
                                                             parse_resource_id_mock,
-                                                            web_client_factory_mock):
+                                                            web_client_factory_mock,
+                                                            check_language_runtime_mock):
         # prepare
         cmd_mock = _get_test_cmd()
         cli_ctx_mock = mock.MagicMock()
@@ -122,17 +146,21 @@ class TestFunctionappMocked(unittest.TestCase):
         web_client_mock.web_apps.get.assert_called_with('rg', 'name')
         upload_zip_to_storage_mock.assert_called_with(cmd_mock, 'rg', 'name', 'src', None)
 
+    @mock.patch('azure.cli.command_modules.appservice.custom.check_language_runtime')
     @mock.patch('azure.cli.command_modules.appservice.custom.web_client_factory', autospec=True)
     @mock.patch('azure.cli.command_modules.appservice.custom.parse_resource_id')
     @mock.patch('azure.cli.command_modules.appservice.custom.validate_zip_deploy_app_setting_exists')
     @mock.patch('azure.cli.command_modules.appservice.custom.upload_zip_to_storage')
     @mock.patch('azure.cli.command_modules.appservice.custom.is_plan_consumption', return_value=True)
+    @mock.patch('azure.cli.command_modules.appservice.custom.is_flex_functionapp', return_value=False)
     def test_functionapp_linux_consumption_non_remote_build_with_slot(self,
+                                                            is_flex_functionapp_mock,
                                                             is_plan_consumption_mock,
                                                             upload_zip_to_storage_mock,
                                                             validate_zip_deploy_app_setting_exists_mock,
                                                             parse_resource_id_mock,
-                                                            web_client_factory_mock):
+                                                            web_client_factory_mock,
+                                                            check_language_runtime_mock):
         # prepare
         cmd_mock = _get_test_cmd()
         cli_ctx_mock = mock.MagicMock()
@@ -154,15 +182,19 @@ class TestFunctionappMocked(unittest.TestCase):
         web_client_mock.web_apps.get.assert_called_with('rg', 'name')
         upload_zip_to_storage_mock.assert_called_with(cmd_mock, 'rg', 'name', 'src', 'slot')
 
+    @mock.patch('azure.cli.command_modules.appservice.custom.check_language_runtime')
     @mock.patch('azure.cli.command_modules.appservice.custom.add_remote_build_app_settings')
     @mock.patch('azure.cli.command_modules.appservice.custom.web_client_factory', autospec=True)
     @mock.patch('azure.cli.command_modules.appservice.custom.parse_resource_id')
+    @mock.patch('azure.cli.command_modules.appservice.custom.is_flex_functionapp', return_value=False)
     @mock.patch('azure.cli.command_modules.appservice.custom.enable_zip_deploy')
     def test_functionapp_remote_build_supports_linux(self,
                                                      enable_zip_deploy_mock,
+                                                     is_flex_functionapp_mock,
                                                      parse_resource_id_mock,
                                                      web_client_factory_mock,
-                                                     add_remote_build_app_settings_mock):
+                                                     add_remote_build_app_settings_mock,
+                                                     check_language_runtime_mock):
         # prepare
         cmd_mock = _get_test_cmd()
         cli_ctx_mock = mock.MagicMock()
@@ -183,6 +215,45 @@ class TestFunctionappMocked(unittest.TestCase):
         web_client_mock.web_apps.get.assert_called_with('rg', 'name')
         enable_zip_deploy_mock.assert_called_with(cmd_mock, 'rg', 'name', 'src', None, None)
 
+    @mock.patch('azure.cli.command_modules.appservice.custom._get_scm_url', return_value='https://mock-scm')
+    @mock.patch('azure.cli.command_modules.appservice.custom.get_runtime_config')
+    @mock.patch('azure.cli.command_modules.appservice.custom.get_scm_site_headers_flex')
+    @mock.patch('requests.post', autospec=True)
+    @mock.patch('azure.cli.command_modules.appservice.custom._check_zip_deployment_status_flex')
+    def test_enable_zip_deploy_flex(self,
+                                    check_zip_deployment_status_mock,
+                                    requests_post_mock,
+                                    get_scm_site_headers_flex_mock,
+                                    get_runtime_config_mock,
+                                    get_scm_url_mock):
+        # prepare
+        cmd_mock = _get_test_cmd()
+        cli_ctx_mock = mock.MagicMock()
+        cmd_mock.cli_ctx = cli_ctx_mock
+
+        response = mock.MagicMock()
+        response.status_code = 202
+        requests_post_mock.return_value = response
+
+        get_runtime_config_mock.return_value = {
+            "name": "java",
+        }
+
+        expected_zip_deploy_headers = _get_flex_zip_deploy_headers(cmd_mock.cli_ctx)
+        get_scm_site_headers_flex_mock.return_value = expected_zip_deploy_headers
+
+        # action
+        with mock.patch('builtins.open', new_callable=mock.mock_open, read_data='zip-content'):
+            enable_zip_deploy_flex(cmd_mock, 'rg', 'name', 'src', slot=None, build_remote=True)
+
+        # assert
+        requests_post_mock.assert_called_with('https://mock-scm/api/publish?RemoteBuild=True&Deployer=az_cli', data='zip-content',
+                                              headers=expected_zip_deploy_headers, verify=mock.ANY)
+        # TODO improve authorization matcher
+        check_zip_deployment_status_mock.assert_called_with(cmd_mock, 'rg', 'name',
+                                                            'https://mock-scm/api/deployments/latest', None)
+
+
     @mock.patch('azure.cli.command_modules.appservice.custom.get_scm_site_headers')
     @mock.patch('azure.cli.command_modules.appservice.custom._get_scm_url', side_effect=ValueError())
     def test_enable_zip_deploy_remote_build_no_scm_site(self,
@@ -203,11 +274,13 @@ class TestFunctionappMocked(unittest.TestCase):
 
     @mock.patch('azure.cli.command_modules.appservice.custom.get_scm_site_headers')
     @mock.patch('azure.cli.command_modules.appservice.custom._get_scm_url', return_value='https://mock-scm')
+    @mock.patch('azure.cli.command_modules.appservice.custom.web_client_factory', autospec=True)
     @mock.patch('requests.post', autospec=True)
     @mock.patch('azure.cli.command_modules.appservice.custom._check_zip_deployment_status')
     def test_enable_zip_deploy_accepted(self,
                                         check_zip_deployment_status_mock,
                                         requests_post_mock,
+                                        web_client_factory_mock,
                                         get_scm_url_mock,
                                         get_scm_headers_mock):
         # prepare
@@ -219,6 +292,14 @@ class TestFunctionappMocked(unittest.TestCase):
         response.status_code = 202
         requests_post_mock.return_value = response
 
+        appservice_mock = mock.Mock()
+        appservice_mock.kind = "functionapp"
+
+        web_client_mock = mock.Mock()
+        web_client_mock.web_apps = mock.Mock()
+        web_client_mock.web_apps.get = mock.Mock(return_value=appservice_mock)
+        web_client_factory_mock.return_value = web_client_mock
+
         expected_zip_deploy_headers = _get_zip_deploy_headers('usr', 'pwd', cmd_mock.cli_ctx)
         get_scm_headers_mock.return_value = expected_zip_deploy_headers
 
@@ -227,7 +308,7 @@ class TestFunctionappMocked(unittest.TestCase):
             enable_zip_deploy(cmd_mock, 'rg', 'name', 'src', slot=None)
 
         # assert
-        requests_post_mock.assert_called_with('https://mock-scm/api/zipdeploy?isAsync=true', data='zip-content',
+        requests_post_mock.assert_called_with('https://mock-scm/api/zipdeploy?isAsync=true&Deployer=az_cli_functions', data='zip-content',
                                               headers=expected_zip_deploy_headers, verify=mock.ANY)
         # TODO improve authorization matcher
         check_zip_deployment_status_mock.assert_called_with(cmd_mock, 'rg', 'name',
@@ -235,9 +316,11 @@ class TestFunctionappMocked(unittest.TestCase):
 
     @mock.patch('azure.cli.command_modules.appservice.custom.get_scm_site_headers')
     @mock.patch('azure.cli.command_modules.appservice.custom._get_scm_url', return_value='https://mock-scm')
+    @mock.patch('azure.cli.command_modules.appservice.custom.web_client_factory', autospec=True)
     @mock.patch('requests.post', autospec=True)
     def test_enable_zip_deploy_conflict(self,
                                         requests_post_mock,
+                                        web_client_factory_mock,
                                         get_scm_url_mock,
                                         get_scm_headers_mock):
         # prepare
@@ -249,6 +332,14 @@ class TestFunctionappMocked(unittest.TestCase):
         response.status_code = 409
         requests_post_mock.return_value = response
 
+        appservice_mock = mock.Mock()
+        appservice_mock.kind = "functionapp"
+
+        web_client_mock = mock.Mock()
+        web_client_mock.web_apps = mock.Mock()
+        web_client_mock.web_apps.get = mock.Mock(return_value=appservice_mock)
+        web_client_factory_mock.return_value = web_client_mock
+
         expected_zip_deploy_headers = _get_zip_deploy_headers('usr', 'pwd', cmd_mock.cli_ctx)
         get_scm_headers_mock.return_value = expected_zip_deploy_headers
 
@@ -258,14 +349,16 @@ class TestFunctionappMocked(unittest.TestCase):
                 enable_zip_deploy(cmd_mock, 'rg', 'name', 'src', slot=None)
 
         # assert
-        requests_post_mock.assert_called_with('https://mock-scm/api/zipdeploy?isAsync=true', data='zip-content',
+        requests_post_mock.assert_called_with('https://mock-scm/api/zipdeploy?isAsync=true&Deployer=az_cli_functions', data='zip-content',
                                               headers=expected_zip_deploy_headers, verify=mock.ANY)
 
     @mock.patch('azure.cli.command_modules.appservice.custom.get_scm_site_headers')
     @mock.patch('azure.cli.command_modules.appservice.custom._get_scm_url', return_value='https://mock-scm')
+    @mock.patch('azure.cli.command_modules.appservice.custom.web_client_factory', autospec=True)
     @mock.patch('requests.post', autospec=True)
     def test_enable_zip_deploy_service_unavailable(self,
                                                    requests_post_mock,
+                                                   web_client_factory_mock,
                                                    get_scm_url_mock,
                                                    get_scm_headers_mock):
         # prepare
@@ -277,6 +370,15 @@ class TestFunctionappMocked(unittest.TestCase):
         response.status_code = 503
         requests_post_mock.return_value = response
 
+        appservice_mock = mock.Mock()
+        appservice_mock.kind = "functionapp"
+
+        web_client_mock = mock.Mock()
+        web_client_mock.web_apps = mock.Mock()
+        web_client_mock.web_apps.get = mock.Mock(return_value=appservice_mock)
+        web_client_factory_mock.return_value = web_client_mock
+
+
         expected_zip_deploy_headers = _get_zip_deploy_headers('usr', 'pwd', cmd_mock.cli_ctx)
         get_scm_headers_mock.return_value = expected_zip_deploy_headers
 
@@ -286,7 +388,7 @@ class TestFunctionappMocked(unittest.TestCase):
                 enable_zip_deploy(cmd_mock, 'rg', 'name', 'src', slot=None)
 
         # assert
-        requests_post_mock.assert_called_with('https://mock-scm/api/zipdeploy?isAsync=true', data='zip-content',
+        requests_post_mock.assert_called_with('https://mock-scm/api/zipdeploy?isAsync=true&Deployer=az_cli_functions', data='zip-content',
                                               headers=expected_zip_deploy_headers, verify=mock.ANY)
 
     @mock.patch('azure.cli.command_modules.appservice.custom._get_app_settings_from_scm', return_value={
@@ -373,6 +475,39 @@ class TestFunctionappMocked(unittest.TestCase):
         # assert
         self.assertFalse(result)
 
+    @mock.patch('azure.cli.command_modules.appservice.custom.check_language_runtime')
+    @mock.patch('azure.cli.command_modules.appservice.custom.is_centauri_functionapp')
+    @mock.patch('azure.cli.command_modules.appservice.custom._generic_site_operation')
+    @mock.patch('azure.cli.command_modules.appservice.custom.update_functionapp_polling', return_value=True)
+    @mock.patch('azure.cli.command_modules.appservice.custom.update_container_settings', autospec=True)
+    def test_update_container_settings_functionapp(self,
+                                                   update_container_settings_mock,
+                                                   update_functionapp_polling_mock,
+                                                   site_op_mock,
+                                                   is_centauri_functionapp_mock,
+                                                   check_language_runtime_mock):
+        # prepare
+        cmd_mock = _get_test_cmd()
+        cli_ctx_mock = mock.MagicMock()
+        cmd_mock.cli_ctx = cli_ctx_mock
+
+        Site, DaprConfig, ResourceConfig = cmd_mock.get_models('Site', 'DaprConfig', 'ResourceConfig')
+        site = Site(dapr_config=None, location='westus', name='name', resource_config=ResourceConfig())
+        site_op_mock.return_value = site
+        
+        is_centauri_functionapp_mock.return_value = True
+
+        check_language_runtime_mock.return_value = True
+
+        # action
+        update_container_settings_functionapp(cmd_mock, 'rg', 'name', workload_profile_name='d4', cpu=0.5, memory='1Gi')
+
+        # assert
+        updated_site = site
+        updated_site.dapr_config = DaprConfig()
+        update_functionapp_polling_mock.assert_called_with(cmd_mock, 'rg', 'name', updated_site)
+
+
     @mock.patch('azure.cli.command_modules.appservice.custom.validate_app_settings_in_scm', return_value=True)
     @mock.patch('azure.cli.command_modules.appservice.custom.update_app_settings')
     @mock.patch('azure.cli.command_modules.appservice.custom.delete_app_settings')
@@ -513,3 +648,36 @@ class TestFunctionappMocked(unittest.TestCase):
         # assert
         update_app_settings_mock.assert_not_called()
         validate_app_settings_in_scm_mock.assert_not_called()
+
+
+    @mock.patch('azure.cli.command_modules.appservice.custom.web_client_factory', autospec=True)
+    @mock.patch('azure.cli.command_modules.appservice.custom._get_location_from_webapp')
+    @mock.patch('azure.cli.command_modules.appservice.custom._generic_site_operation', autospec=True)
+    @mock.patch('azure.cli.command_modules.appservice.custom.LongRunningOperation.__call__', autospec=True)
+    def test_config_source_control(self,
+                                   long_running_operation_mock,
+                                   site_op_mock,
+                                   location_mock,
+                                   web_client_factory_mock):
+        # prepare
+        client = mock.Mock()
+        web_client_factory_mock.return_value = client
+
+        location_mock.return_value = mock.MagicMock()
+
+        site_op_mock.return_value = mock.MagicMock()
+
+        cmd_mock = _get_test_cmd()
+
+        SiteSourceControl, GitHubActionConfiguration, GitHubActionContainerConfiguration = cmd_mock.get_models('SiteSourceControl', 'GitHubActionConfiguration', 'GitHubActionContainerConfiguration')
+        container_config = GitHubActionContainerConfiguration(username="username", password="password")
+        github_action_config = GitHubActionConfiguration(container_configuration=container_config)
+        source_control = SiteSourceControl(git_hub_action_configuration=github_action_config)
+
+        long_running_operation_mock.return_value = source_control
+
+        # action
+        response = config_source_control(cmd_mock, 'rg', 'functionapp', 'https://github.com/yugang/azure-site-test')
+
+        # assert
+        self.assertEqual(response.git_hub_action_configuration.container_configuration.password, None)
