@@ -10,7 +10,7 @@ def add_tags(command, tags):
 
 # pylint: disable=too-many-public-methods
 class CdnScenarioMixin:
-    def profile_create_cmd(self, group, name, tags=None, checks=None, options=None, sku=None):
+    def profile_create_cmd(self, group, name, tags=None, checks=None, options=None, sku='STANDARD_MICROSOFT'):
         command = 'cdn profile create -g {} -n {}'.format(group, name)
         if tags:
             command = command + ' --tags {}'.format(tags)
@@ -410,3 +410,26 @@ class CdnScenarioMixin:
 
     def resource_id_prefix(self, resource_group):
         return f'/subscriptions/{self.get_subscription_id()}/resourceGroups/{resource_group}/providers/Microsoft.Cdn'
+
+    def cdn_can_migrate_to_afd(self, resource_group, profile_name, checks=None):
+        command = 'cdn profile-migration check-compatibility -g {} --profile-name {}'.format(resource_group,
+                                                                                             profile_name)
+        return self.cmd(command, checks)
+
+    def cdn_migrate_to_afd(self, resource_group, profile_name, sku, migration_endpoint_mappings=None, checks=None):
+        command = 'cdn profile-migration migrate -g {} --profile-name {} --sku {} --identity-type SystemAssigned'.format(resource_group,
+                                                                                                                         profile_name, sku)
+        if migration_endpoint_mappings is not None:
+            command += ' --migration-endpoint-mappings {}'.format(migration_endpoint_mappings)
+
+        return self.cmd(command, checks)
+
+    def cdn_migration_abort(self, resource_group, profile_name, checks=None):
+        command = 'cdn profile-migration abort -g {} --profile-name {}'.format(resource_group,
+                                                                               profile_name)
+        return self.cmd(command, checks)
+
+    def cdn_migration_commit(self, resource_group, profile_name, checks=None):
+        command = 'cdn profile-migration commit -g {} --profile-name {}'.format(resource_group,
+                                                                                profile_name)
+        return self.cmd(command, checks)
