@@ -13,6 +13,7 @@ from azure.core.exceptions import (HttpResponseError, ResourceNotFoundError, Res
 from knack.util import CLIError
 
 
+# To run this test, please edit https://ms.portal.azure.com/#@microsoft.onmicrosoft.com/resource/subscriptions/27cafca8-b9a4-4264-b399-45d0c9cca1ab/resourceGroups/CliDevReservedGroup/providers/Microsoft.Network/dnszones/afdx-rp-platform-test.azfdtest.xyz/recordsets
 class CdnCustomDomainScenarioTest(CdnScenarioMixin, ScenarioTest):
     @ResourceGroupPreparer(name_prefix='cli_test_cdn_domain', additional_tags={'owner': 'jingnanxu'})
     def test_cdn_custom_domain_errors(self, resource_group):
@@ -54,7 +55,7 @@ class CdnCustomDomainScenarioTest(CdnScenarioMixin, ScenarioTest):
         # Endpoint name and custom domain hostname are hard-coded because of
         # custom domain CNAME requirement. If test fails to cleanup, the
         # resource group must be manually deleted in order to re-run.
-        endpoint_name = 'aaz-09-01-crud'
+        endpoint_name = 'aaz-06-01-crud'
         origin = 'www.microsoft1.com'
         self.endpoint_create_cmd(resource_group, endpoint_name, profile_name, origin)
 
@@ -82,44 +83,6 @@ class CdnCustomDomainScenarioTest(CdnScenarioMixin, ScenarioTest):
         list_checks = [JMESPathCheck('length(@)', 0)]
         self.custom_domain_list_cmd(resource_group, profile_name, endpoint_name, checks=list_checks)
 
-    @ResourceGroupPreparer(additional_tags={'owner': 'jingnanxu'})
-    def test_cdn_custom_domain_https_verizon(self, resource_group):
-        profile_name = 'profile123'
-        self.endpoint_list_cmd(resource_group, profile_name, expect_failure=True)
-
-        self.profile_create_cmd(resource_group, profile_name, sku=SkuName.standard_verizon.value)
-        # Endpoint name and custom domain hostname are hard-coded because of
-        # custom domain CNAME requirement. If test fails to cleanup, the
-        # resource group must be manually deleted in order to re-run.
-        endpoint_name = 'aaz-09-01-verizon'
-        origin = 'www.microsoft1.com'
-        self.endpoint_create_cmd(resource_group, endpoint_name, profile_name, origin).get_output_in_json()
-
-        custom_domain_name = self.create_random_name(prefix='customdomain', length=20)
-        hostname = custom_domain_name + '.aaz0901-verizon.clitest.azfdtest.xyz'
-        # # Use alternate hostnames for dogfood.
-        # if '.azureedge-test.net' in endpoint['hostName']:
-        #     hostname = custom_domain_name + '.aaz0901-verizon-fd.clitest.azfdtest.xyz'
-        self.custom_domain_create_cmd(resource_group, profile_name, endpoint_name, custom_domain_name, hostname)
-
-        checks = [JMESPathCheck('name', custom_domain_name),
-                  JMESPathCheck('hostName', hostname),
-                  JMESPathCheck('customHttpsParameters', None)]
-        self.custom_domain_show_cmd(resource_group, profile_name, endpoint_name, custom_domain_name, checks=checks)
-
-        checks = [JMESPathCheck('name', custom_domain_name),
-                  JMESPathCheck('hostName', hostname),
-                  JMESPathCheck('customHttpsProvisioningState', 'Enabling'),
-                  JMESPathCheck('customHttpsProvisioningSubstate', 'SubmittingDomainControlValidationRequest')]
-        self.custom_domain_enable_https_command(resource_group,
-                                                profile_name,
-                                                endpoint_name,
-                                                custom_domain_name,
-                                                min_tls_version='None',
-                                                checks=checks)
-
-        self.custom_domain_disable_https_cmd(resource_group, profile_name, endpoint_name, custom_domain_name)
-
     @ResourceGroupPreparer(additional_tags={'owner': 'jingnanxu'})
     # need to switch to a different subscription 3c0124f9-e564-4c42-86f7-fa79457aedc3
     # @KeyVaultPreparer(location='centralus', name_prefix='cdncli-byoc', name_len=24)
@@ -131,15 +94,15 @@ class CdnCustomDomainScenarioTest(CdnScenarioMixin, ScenarioTest):
         # Endpoint name and custom domain hostname are hard-coded because of
         # custom domain CNAME requirement. If test fails to cleanup, the
         # resource group must be manually deleted in order to re-run.
-        endpoint_name = 'aaz-byoc-6'
+        endpoint_name = 'msft-byoc-071401'
         origin = 'www.microsoft1.com'
         self.endpoint_create_cmd(resource_group, endpoint_name, profile_name, origin).get_output_in_json()
 
         # Create custom domains for CDN managed cert and BYOC
-        custom_domain_name = "msft-c"
-        byoc_custom_domain_name = "msft-b"
-        hostname = custom_domain_name + '-aaz0901.afdx-rp-platform-test.azfdtest.xyz'
-        byoc_hostname = byoc_custom_domain_name + '-aaz0901.afdx-rp-platform-test.azfdtest.xyz'
+        custom_domain_name = "msft-0601-c"
+        byoc_custom_domain_name = "msft-0601-b"
+        hostname = custom_domain_name + '-h.afdx-rp-platform-test.azfdtest.xyz'
+        byoc_hostname = byoc_custom_domain_name + '-h.afdx-rp-platform-test.azfdtest.xyz'
         # # Use alternate hostnames for dogfood.
         # if '.azureedge-test.net' in endpoint['hostName']:
         #     hostname = custom_domain_name + '.aaz0901-byoc-fd.clitest.azfdtest.xyz'
@@ -169,7 +132,7 @@ class CdnCustomDomainScenarioTest(CdnScenarioMixin, ScenarioTest):
                                                 min_tls_version='1.2',
                                                 checks=checks)
 
-        version = "634c38a587884de4980f1b8c1c368712"
+        version = "5b70b55164af4b1d8bf3c560dc28fa71"
 
         # Enable custom HTTPS with a custom certificate
         # With the latest service side change to move the certificate validation to RP layer, the request will be rejected.
@@ -197,13 +160,13 @@ class CdnCustomDomainScenarioTest(CdnScenarioMixin, ScenarioTest):
         # Endpoint name and custom domain hostname are hard-coded because of
         # custom domain CNAME requirement. If test fails to cleanup, the
         # resource group must be manually deleted in order to re-run.
-        endpoint_name = 'aaz-byoc-4'
+        endpoint_name = 'byoc-l-071401'
         origin = 'www.microsoft1.com'
         self.endpoint_create_cmd(resource_group, endpoint_name, profile_name, origin).get_output_in_json()
 
         # Create custom domain for BYOC
-        custom_domain_name = "byoc-c"
-        hostname = custom_domain_name + '-aaz0901.afdx-rp-platform-test.azfdtest.xyz'
+        custom_domain_name = "byoc"
+        hostname = custom_domain_name + '-0601.afdx-rp-platform-test.azfdtest.xyz'
         # # Use alternate hostname for dogfood.
         # if '.azureedge-test.net' in endpoint['hostName']:
         #     hostname = custom_domain_name + '.aaz-5-df.clitest.azfdtest.xyz'
