@@ -1,4 +1,4 @@
-# --------------------------------------------------------------------------------------------
+
 # Copyright (c) Microsoft Corporation. All rights reserved.
 # Licensed under the MIT License. See License.txt in the project root for license information.
 # --------------------------------------------------------------------------------------------
@@ -202,47 +202,6 @@ class CdnEndpointScenarioTest(CdnScenarioMixin, ScenarioTest):
         self.endpoint_start_cmd(resource_group, endpoint_name, profile_name)
         self.endpoint_show_cmd(resource_group, endpoint_name, profile_name, checks=checks)
 
-    @ResourceGroupPreparer(additional_tags={'owner': 'jingnanxu'})
-    def test_endpoint_load_and_purge(self, resource_group):
-        profile_name = 'profile123'
-        self.profile_create_cmd(resource_group, profile_name, sku='Standard_Verizon')
-
-        endpoint_name = self.create_random_name(prefix='endpoint', length=24)
-        origin = 'www.contoso.com'
-        self.endpoint_create_cmd(resource_group, endpoint_name, profile_name, origin)
-
-        content_paths = ['/index.html', '/javascript/app.js']
-        self.endpoint_load_cmd(resource_group, endpoint_name, profile_name, content_paths)
-
-        content_paths = ['/index.html', '/javascript/*']
-        self.endpoint_purge_cmd(resource_group, endpoint_name, profile_name, content_paths)
-
-    @ResourceGroupPreparer()
-    def test_endpoint_different_profiles(self, resource_group):
-        origin = 'www.contoso.com'
-        checks = [JMESPathCheck('origins[0].hostName', origin),
-                  JMESPathCheck('isHttpAllowed', True),
-                  JMESPathCheck('isHttpsAllowed', True),
-                  JMESPathCheck('isCompressionEnabled', False),
-                  JMESPathCheck('queryStringCachingBehavior', 'IgnoreQueryString')]
-
-        # create an endpoint using the standard_verizon profile
-        profile_name = self._create_profile(resource_group, SkuName.standard_verizon.value)
-        endpoint_name = self.create_random_name(prefix='endpoint', length=24)
-        self.endpoint_create_cmd(resource_group, endpoint_name, profile_name, origin, checks=checks + [JMESPathCheck('name', endpoint_name)])
-
-        # create an endpoint using the premium_verizon profile
-        profile_name = self._create_profile(resource_group, SkuName.premium_verizon.value)
-        endpoint_name = self.create_random_name(prefix='endpoint', length=24)
-        premium_checks = checks.extend([JMESPathCheck('queryStringCachingBehavior', 'NotSet'), JMESPathCheck('name', endpoint_name)])
-        self.endpoint_create_cmd(resource_group, endpoint_name, profile_name, origin, checks=premium_checks)
-
-    def _create_profile(self, resource_group, profile_sku):
-        profile_name = (profile_sku + "_profile").replace("_", "-")  # profile names must match ^[a-zA-Z0-9]+(-*[a-zA-Z0-9])*$
-        check = JMESPathCheck('sku.name', profile_sku)
-        self.profile_create_cmd(resource_group, profile_name, sku=profile_sku, checks=check)
-        return profile_name
-
     @ResourceGroupPreparer()
     def test_rule_engine_crud(self, resource_group):
         profile_name = 'profile123'
@@ -369,76 +328,3 @@ class CdnEndpointScenarioTest(CdnScenarioMixin, ScenarioTest):
                                       options='--rule-name r3')
 
         self.endpoint_delete_cmd(resource_group, endpoint_name, profile_name)
-
-    @ResourceGroupPreparer()
-    def test_verizon_delivery_rule(self, resource_group):
-        self._test_delivery_rule_internal(resource_group, "akp", "Standard_Verizon")
-
-    def _test_delivery_rule_internal(self, resource_group, profile_prefix, sku):
-        profile_name = self.create_random_name(prefix=profile_prefix, length=24)
-        self.profile_create_cmd(resource_group, profile_name, sku=sku)
-        endpoint_name = self.create_random_name(prefix='endpoint', length=24)
-        origin = 'huaiyiztesthost1.blob.core.chinacloudapi.cn'
-        checks = [JMESPathCheck('name', endpoint_name),
-                  JMESPathCheck('origins[0].hostName', origin),
-                  JMESPathCheck('isHttpAllowed', True),
-                  JMESPathCheck('isHttpsAllowed', True),
-                  JMESPathCheck('isCompressionEnabled', False),
-                  JMESPathCheck('queryStringCachingBehavior', 'IgnoreQueryString')]
-        self.endpoint_create_cmd(resource_group, endpoint_name, profile_name, origin, checks=checks)
-
-        # Add global rule
-        rule_add_checks = [JMESPathCheck('length(deliveryPolicy.rules)', 1),
-                           JMESPathCheck('deliveryPolicy.rules[0].name', None)]
-        rule_add_command = f'az cdn endpoint rule add -g {resource_group} -n {endpoint_name} --profile-name {profile_name} --order 0 '\
-            '--action-name CacheExpiration --cache-behavior Override --cache-duration 00:05:00'
-        self.cmd(rule_add_command, rule_add_checks)
-
-        # Add file path rule
-        rule_add_checks = [JMESPathCheck('length(deliveryPolicy.rules)', 2),
-                           JMESPathCheck('deliveryPolicy.rules[1].name', None),
-                           JMESPathCheck('deliveryPolicy.rules[1].actions[0].name', "CacheExpiration"),
-                           JMESPathCheck('deliveryPolicy.rules[1].conditions[0].name', "UrlPath"),
-                           JMESPathCheck('deliveryPolicy.rules[1].conditions[0].parameters.matchType', "Wildcard"),
-                           JMESPathCheck('deliveryPolicy.rules[1].conditions[0].parameters.path', "/test2/*")]
-        rule_add_command = f'az cdn endpoint rule add -g {resource_group} -n {endpoint_name} --profile-name {profile_name} --order 1 '\
-            '--action-name CacheExpiration --match-variable UrlPath --operator Wildcard --match-values /test2/* '\
-            '--cache-behavior Override --cache-duration 00:05:00'
-        self.cmd(rule_add_command, rule_add_checks)
-
-        # Add file extension rule
-        rule_add_checks = [JMESPathCheck('length(deliveryPolicy.rules)', 3),
-                           JMESPathCheck('deliveryPolicy.rules[2].name', None),
-                           JMESPathCheck('deliveryPolicy.rules[2].conditions[0].name', "UrlFileExtension"),
-                           JMESPathCheck('deliveryPolicy.rules[2].conditions[0].parameters.extensions[0]', "mp4"),
-                           JMESPathCheck('deliveryPolicy.rules[2].conditions[0].parameters.extensions[1]', "mp3")]
-        rule_add_command = f'az cdn endpoint rule add -g {resource_group} -n {endpoint_name} --profile-name {profile_name} --order 2 '\
-            '--action-name CacheExpiration --match-variable UrlFileExtension --operator Any --match-values mp4 mp3 '\
-            '--cache-behavior Override --cache-duration 00:05:00'
-        self.cmd(rule_add_command, rule_add_checks)
-
-        delete_checks = [JMESPathCheck('name', endpoint_name),
-                         JMESPathCheck('length(deliveryPolicy.rules)', 2)]
-        self.endpoint_remove_rule_cmd(resource_group,
-                                      endpoint_name,
-                                      profile_name,
-                                      checks=delete_checks,
-                                      options='--order 2')
-
-        delete_checks = [JMESPathCheck('name', endpoint_name),
-                         JMESPathCheck('length(deliveryPolicy.rules)', 1)]
-        self.endpoint_remove_rule_cmd(resource_group,
-                                      endpoint_name,
-                                      profile_name,
-                                      checks=delete_checks,
-                                      options='--order 1')
-
-        delete_checks = [JMESPathCheck('name', endpoint_name),
-                         JMESPathCheck('length(deliveryPolicy.rules)', 0)]
-        self.endpoint_remove_rule_cmd(resource_group,
-                                      endpoint_name,
-                                      profile_name,
-                                      checks=delete_checks,
-                                      options='--order 0')
-
-        self.endpoint_delete_cmd(resource_group, endpoint_name, profile_name)
