@@ -92,4 +92,13 @@ def create_and_verify_containerapp_up(
         # Re-run the 'az containerapp up' command with the location parameter if provided
         if location:
             up_cmd += f" -l {location.upper()}"
-            test_cls.cmd(up_cmd)
\ No newline at end of file
+            test_cls.cmd(up_cmd)
+
+
+def create_vnet_subnet(self, resource_group, vnet, delegations='Microsoft.App/environments', location="centralus"):
+    self.cmd(f"az network vnet create --address-prefixes '14.0.0.0/23' -g {resource_group} -n {vnet} --location {location}")
+    subnet_command = f"az network vnet subnet create --address-prefixes '14.0.0.0/23' -n sub -g {resource_group} --vnet-name {vnet}"
+    if delegations is not None:
+        subnet_command += f' --delegations {delegations}'
+    sub_id = self.cmd(subnet_command).get_output_in_json()["id"]
+    return sub_id
\ No newline at end of file
