@@ -14,8 +14,8 @@ TEST_DIR = os.path.abspath(os.path.join(os.path.abspath(__file__), '..'))
 
 
 class HDInsightClusterTests(ScenarioTest):
-    location = 'eastus'
-    vnet_id = '/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/yuchen-ps-test/providers/Microsoft.Network/virtualNetworks/hdi-vn-0'
+    location = 'EastAsia'
+    vnet_id = '/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/rg/providers/Microsoft.Network/virtualNetworks/hdi-vn-0'
     subnet = 'default'
 
     # Uses 'rg' kwarg
@@ -31,7 +31,8 @@ class HDInsightClusterTests(ScenarioTest):
     @StorageAccountPreparer(name_prefix='hdicli', location=location, parameter_name='storage_account')
     def test_hdinsight_cluster_resize(self, storage_account_info):
         self._create_hdinsight_cluster(
-            self._wasb_arguments(storage_account_info))
+            self._wasb_arguments(storage_account_info),
+            self._vnet_arguments())
 
         resize_cluster_format = 'az hdinsight resize -n {cluster} -g {rg} --workernode-count 2'
         self.cmd(resize_cluster_format)
@@ -49,7 +50,8 @@ class HDInsightClusterTests(ScenarioTest):
     def test_hdinsight_cluster_kafka(self, storage_account_info):
         self._create_hdinsight_cluster(
             HDInsightClusterTests._wasb_arguments(storage_account_info),
-            HDInsightClusterTests._kafka_arguments()
+            HDInsightClusterTests._kafka_arguments(),
+            HDInsightClusterTests._vnet_arguments()
         )
 
     # Uses 'rg' kwarg
@@ -71,7 +73,8 @@ class HDInsightClusterTests(ScenarioTest):
         self._create_hdinsight_cluster(
             HDInsightClusterTests._wasb_arguments(storage_account_info),
             HDInsightClusterTests._kafka_arguments(),
-            HDInsightClusterTests._optional_data_disk_arguments()
+            HDInsightClusterTests._optional_data_disk_arguments(),
+            HDInsightClusterTests._vnet_arguments()
         )
 
     # Uses 'rg' kwarg
@@ -89,7 +92,8 @@ class HDInsightClusterTests(ScenarioTest):
     def test_hdinsight_cluster_with_cluster_config(self, storage_account_info):
         self._create_hdinsight_cluster(
             HDInsightClusterTests._wasb_arguments(storage_account_info),
-            HDInsightClusterTests._with_cluster_config()
+            HDInsightClusterTests._with_cluster_config(),
+            HDInsightClusterTests._vnet_arguments()
         )
 
     # Uses 'rg' kwarg
@@ -98,7 +102,8 @@ class HDInsightClusterTests(ScenarioTest):
     def test_hdinsight_cluster_with_ssh_creds(self, storage_account_info):
         self._create_hdinsight_cluster(
             HDInsightClusterTests._wasb_arguments(storage_account_info),
-            HDInsightClusterTests._with_explicit_ssh_creds()
+            HDInsightClusterTests._with_explicit_ssh_creds(),
+            HDInsightClusterTests._vnet_arguments()
         )
 
     @ResourceGroupPreparer(name_prefix='hdicli-', location=location, random_name_length=12)
@@ -106,7 +111,8 @@ class HDInsightClusterTests(ScenarioTest):
     def test_hdinsight_cluster_with_minimal_tls_version(self, storage_account_info):
         self._create_hdinsight_cluster(
             HDInsightClusterTests._wasb_arguments(storage_account_info),
-            HDInsightClusterTests._with_minimal_tls_version('1.2')
+            HDInsightClusterTests._with_minimal_tls_version('1.2'),
+            HDInsightClusterTests._vnet_arguments()
         )
 
         self.cmd('az hdinsight show -n {cluster} -g {rg}', checks=[
@@ -119,7 +125,8 @@ class HDInsightClusterTests(ScenarioTest):
     def test_hdinsight_cluster_with_encryption_in_transit(self, storage_account_info):
         self._create_hdinsight_cluster(
             HDInsightClusterTests._wasb_arguments(storage_account_info),
-            HDInsightClusterTests._with_encryption_in_transit()
+            HDInsightClusterTests._with_encryption_in_transit(),
+            HDInsightClusterTests._vnet_arguments()
         )
 
         self.cmd('az hdinsight show -n {cluster} -g {rg}', checks=[
@@ -132,7 +139,8 @@ class HDInsightClusterTests(ScenarioTest):
     def test_hdinsight_cluster_with_loadbased_autoscale(self, storage_account_info):
         self._create_hdinsight_cluster(
             HDInsightClusterTests._wasb_arguments(storage_account_info),
-            HDInsightClusterTests._with_load_based_autoscale()
+            HDInsightClusterTests._with_load_based_autoscale(),
+            HDInsightClusterTests._vnet_arguments()
         )
         self.cmd('az hdinsight show -n {cluster} -g {rg}', checks=[
             self.check('properties.clusterState', 'Running'),
@@ -146,7 +154,8 @@ class HDInsightClusterTests(ScenarioTest):
     def test_hdinsight_cluster_with_schedulebased_autoscale(self, storage_account_info):
         self._create_hdinsight_cluster(
             HDInsightClusterTests._wasb_arguments(storage_account_info),
-            HDInsightClusterTests._with_schedule_based_autoscale()
+            HDInsightClusterTests._with_schedule_based_autoscale(),
+            HDInsightClusterTests._vnet_arguments()
         )
         self.cmd('az hdinsight show -n {cluster} -g {rg}', checks=[
             self.check('properties.clusterState', 'Running'),
@@ -232,7 +241,8 @@ class HDInsightClusterTests(ScenarioTest):
     def test_hdinsight_application(self, storage_account_info):
         self._create_hdinsight_cluster(
             HDInsightClusterTests._wasb_arguments(storage_account_info),
-            HDInsightClusterTests._with_explicit_ssh_creds()
+            HDInsightClusterTests._with_explicit_ssh_creds(),
+            HDInsightClusterTests._vnet_arguments()
         )
 
         # define application item names
@@ -271,7 +281,7 @@ class HDInsightClusterTests(ScenarioTest):
 
         self.cmd('az hdinsight list-usage -l {loc}', checks=[
             self.check('type(value)', 'array'),
-            self.check('length(value)', 1)
+            self.check('length(value)', 12)
         ])
 
     # Uses 'rg' kwarg
@@ -290,7 +300,8 @@ class HDInsightClusterTests(ScenarioTest):
 
         self._create_hdinsight_cluster(
             HDInsightClusterTests._wasb_arguments(storage_account_info),
-            HDInsightClusterTests._with_explicit_ssh_creds()
+            HDInsightClusterTests._with_explicit_ssh_creds(),
+            HDInsightClusterTests._vnet_arguments()
         )
 
         # get monitor status
@@ -333,7 +344,8 @@ class HDInsightClusterTests(ScenarioTest):
 
         self._create_hdinsight_cluster(
             HDInsightClusterTests._wasb_arguments(storage_account_info),
-            HDInsightClusterTests._with_explicit_ssh_creds()
+            HDInsightClusterTests._with_explicit_ssh_creds(),
+            HDInsightClusterTests._vnet_arguments()
         )
 
         # get monitor status
@@ -493,10 +505,12 @@ class HDInsightClusterTests(ScenarioTest):
     @StorageAccountPreparer(name_prefix='hdicli', location=location, parameter_name='storage_account')
     def test_hdinsight_autoscale_operation(self, storage_account_info):
         self._create_hdinsight_cluster(
-            HDInsightClusterTests._wasb_arguments(storage_account_info)
+            HDInsightClusterTests._wasb_arguments(storage_account_info),
+            HDInsightClusterTests._vnet_arguments()
         )
 
         # enable load-based autoscale
+        HDInsightClusterTests.wait_for_hdinsight_cluster_running(self)
         self.cmd(
             'az hdinsight autoscale create --cluster-name {cluster} --resource-group {rg} --type Load '
             '--min-workernode-count 4 --max-workernode-count 5 --yes')
@@ -506,10 +520,8 @@ class HDInsightClusterTests(ScenarioTest):
                 "properties.computeProfile.roles[?name=='workernode'].autoscaleConfiguration.capacity.minInstanceCount",
                 [4])
         ])
-
+        HDInsightClusterTests.wait_for_hdinsight_cluster_running(self)
         # to get robust
-        import time
-        time.sleep(150)
         # update load-based autoscale
         self.cmd(
             'az hdinsight autoscale update --cluster-name {cluster} --resource-group {rg} --min-workernode-count 3')
@@ -519,36 +531,34 @@ class HDInsightClusterTests(ScenarioTest):
                 "properties.computeProfile.roles[?name=='workernode'].autoscaleConfiguration.capacity.minInstanceCount",
                 [3])
         ])
-
+        HDInsightClusterTests.wait_for_hdinsight_cluster_running(self)
         # show autoscale configuration
         self.cmd('az hdinsight autoscale show --cluster-name {cluster} --resource-group {rg}', checks=[
             self.check("capacity.minInstanceCount", 3)
         ])
-
+        HDInsightClusterTests.wait_for_hdinsight_cluster_running(self)
         # disable autoscale
         self.cmd('az hdinsight autoscale delete --cluster-name {cluster} --resource-group {rg} --yes')
         self.cmd('az hdinsight show --name {cluster} --resource-group {rg}')
-
         # to get robust
-        time.sleep(150)
+        HDInsightClusterTests.wait_for_hdinsight_cluster_running(self)
         # enable schedule-based autoscale
         self.cmd(
             'az hdinsight autoscale create --cluster-name {cluster} --resource-group {rg} --type Schedule --timezone '
             '"China Standard Time" --days Monday --time 09:00 --workernode-count 4 --yes')
+        HDInsightClusterTests.wait_for_hdinsight_cluster_running(self)
         self.cmd('az hdinsight autoscale show --cluster-name {cluster} --resource-group {rg}', checks=[
             self.check("recurrence.schedule[0].days", ["Monday"])
         ])
-
-        time.sleep(120)
-        # add a new schedule condition
+        HDInsightClusterTests.wait_for_hdinsight_cluster_running(self)
+        # add a new schedule condition/
         self.cmd(
             'az hdinsight autoscale condition create --cluster-name {cluster} --resource-group {rg} --days Tuesday '
             '--time 08:00 --workernode-count 5')
         self.cmd('az hdinsight autoscale show --cluster-name {cluster} --resource-group {rg}', checks=[
             self.check("recurrence.schedule[1].days", ["Tuesday"])
         ])
-
-        time.sleep(120)
+        HDInsightClusterTests.wait_for_hdinsight_cluster_running(self)
         # update schedule condition
         self.cmd(
             'az hdinsight autoscale condition update --cluster-name {cluster} --resource-group {rg} '
@@ -556,13 +566,10 @@ class HDInsightClusterTests(ScenarioTest):
         self.cmd('az hdinsight autoscale show --cluster-name {cluster} --resource-group {rg}', checks=[
             self.check("recurrence.schedule[1].timeAndCapacity.minInstanceCount", 4)
         ])
-
         # list schedule conditions
         self.cmd('az hdinsight autoscale condition list --cluster-name {cluster} --resource-group {rg}', checks=[
             self.check('length(@)', 2)
         ])
-
-        time.sleep(120)
         # delete schedule condition
         self.cmd(
             'az hdinsight autoscale condition delete --cluster-name {cluster} --resource-group {rg} --index 1 --yes')
@@ -573,10 +580,10 @@ class HDInsightClusterTests(ScenarioTest):
     def test_hdinsight_azure_monitor_agent(self):
         self.kwargs.update({
             'loc': self.location,
-            'cluster': 'spark51',
-            'rg': 'yuchen-ps-test',
-            'workspace_id': '/subscriptions/00000000-0000-0000-0000-000000000000/resourcegroups/yuchen-ps-test/providers/microsoft.operationalinsights/workspaces/ps-la',
-            'workspace_key': self.cmd('az monitor log-analytics workspace get-shared-keys --resource-group yuchen-ps-test --workspace-name ps-la --query primarySharedKey -o tsv').output.strip(),
+            'cluster': 'cli-test-cluster',
+            'rg': 'cli-test-rg',
+            'workspace_id': '/subscriptions/00000000-0000-0000-0000-000000000000/resourcegroups/cli-test-rg/providers/microsoft.operationalinsights/workspaces/ps-la',
+            'workspace_key': self.cmd('az monitor log-analytics workspace get-shared-keys --resource-group cli-test-rg --workspace-name ps-la --query primarySharedKey -o tsv').output.strip(),
         })
 
         # enable azure monitor agent
@@ -592,9 +599,8 @@ class HDInsightClusterTests(ScenarioTest):
     @StorageAccountPreparer(name_prefix='hdicli', location=location, parameter_name='storage_account')
     def test_hdinsight_update_user_assigned(self, storage_account_info):
         self.kwargs.update({
-            'msi1': '/subscriptions/00000000-0000-0000-0000-000000000000/resourcegroups/yuchen-ps-test/providers/microsoft.managedidentity/userassignedidentities/hdi-msi',
+            'msi1': '/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/rg/providers/Microsoft.ManagedIdentity/userAssignedIdentities/msi',
         })
-
         self._create_hdinsight_cluster(
             HDInsightClusterTests._wasb_arguments(storage_account_info),
             HDInsightClusterTests._vnet_arguments()
@@ -628,8 +634,8 @@ class HDInsightClusterTests(ScenarioTest):
     @StorageAccountPreparer(name_prefix='hdicli', location=location, parameter_name='storage_account')
     def test_hdinsight_update_system_and_user_assigned(self, storage_account_info):
         self.kwargs.update({
-            'msi1': '/subscriptions/00000000-0000-0000-0000-000000000000/resourcegroups/yuchen-ps-test/providers/microsoft.managedidentity/userassignedidentities/hdi-msi',
-            'msi2': '/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/yuchen-devrp/providers/Microsoft.ManagedIdentity/userAssignedIdentities/hdiwasbmsi'
+            'msi1': '/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/rg/providers/Microsoft.ManagedIdentity/userAssignedIdentities/msi',
+            'msi2': '/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/rg/providers/Microsoft.ManagedIdentity/userAssignedIdentities/msi2'
         })
         self._create_hdinsight_cluster(
             HDInsightClusterTests._wasb_arguments(storage_account_info),
@@ -643,11 +649,60 @@ class HDInsightClusterTests(ScenarioTest):
                 self.check('identity.type', 'SystemAssigned,UserAssigned'),
             ])
 
+    @AllowLargeResponse()
+    @ResourceGroupPreparer(name_prefix='hdicli-', location=location, random_name_length=12)
+    def test_hdinsight_create_with_wasb_and_msi(self):
+        storage_account_info = ("hdi-storage-wasb","")
+        msi = "/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/rg/providers/Microsoft.ManagedIdentity/userAssignedIdentities/msi"
+        self._create_hdinsight_cluster(
+            HDInsightClusterTests._wasb_arguments(storage_account_info,msi = msi),
+            HDInsightClusterTests._vnet_arguments()
+        )
+
+    @AllowLargeResponse()
+    @ResourceGroupPreparer(name_prefix='hdicli-', location=location, random_name_length=12)
+    def test_hdinsight_create_with_ADLSGen2_and_msi(self):
+        storage_account_info = "hdi-storage-adlsgen2"
+        msi = "/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/rg/providers/Microsoft.ManagedIdentity/userAssignedIdentities/msi"
+        self._create_hdinsight_cluster(
+            HDInsightClusterTests._adlsgen2_arguments(storage_account_info,specify_filesystem=False,msi = msi),
+            HDInsightClusterTests._vnet_arguments()
+        )
+
+    @AllowLargeResponse()
+    @ResourceGroupPreparer(name_prefix='hdicli-', location=location, random_name_length=12)
+    def test_hdinsight_create_with_entra_user(self):
+        storage_account_info = ("hdicli000002","")
+        msi = '/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/rg/providers/Microsoft.ManagedIdentity/userAssignedIdentities/msi'
+        entra = '"00000000-0000-0000-0000-000000000000","test@example.com"'
+        self._create_hdinsight_cluster(
+            HDInsightClusterTests._wasb_arguments(storage_account_info,msi=msi),
+            HDInsightClusterTests._entra_arguments(entra_user=entra),
+            HDInsightClusterTests._vnet_arguments()
+        )
+        self.kwargs.update({
+            'config_path': os.path.join(TEST_DIR, 'entrauserconfig.json'),
+            'upn1':'test1@example.com',
+            'upn2':'test2@example.com'
+        })
+        self.cmd('az hdinsight credentials update --name {cluster} --resource-group {rg} --entra-uinfo @"{config_path}" --yes')
+        self.cmd('az hdinsight credentials update --name {cluster} --resource-group {rg} --entra-uid {upn1} {upn2} --yes')
+        self.cmd('az hdinsight credentials show -n {cluster} --resource-group {rg}')
+
+    @AllowLargeResponse()
+    def test_hdinsight_credentials_update(self):
+        self.kwargs.update({
+            'cluster': 'cli-test-cluster',
+            'rg': 'cli-test-rg',
+            'http_password': 'Password1!'
+        })
+        self.cmd('az hdinsight credentials wait --name {cluster} --resource-group {rg} --exists')
+        self.cmd('az hdinsight credentials update --name {cluster} --resource-group {rg} --http-password {http_password} --yes')
 
     def _create_hdinsight_cluster(self, *additional_create_arguments):
         self.kwargs.update({
             'loc': self.location,
-            'cluster': self.create_random_name(prefix='hdicli-', length=16),
+            'cluster': self.create_random_name(prefix='cli-', length=16),
             'http_password': 'Password1!',
             'cluster_type': 'spark',
         })
@@ -674,15 +729,23 @@ class HDInsightClusterTests(ScenarioTest):
         ])
 
     @staticmethod
-    def _wasb_arguments(storage_account_info, specify_key=False, specify_container=True):
+    def _wasb_arguments(storage_account_info, specify_key=False, specify_container=True, msi = None):
         storage_account_name, storage_account_key = storage_account_info
         storage_account_key = storage_account_key.strip()
 
         key_args = ' --storage-account-key "{}"'.format(storage_account_key) if specify_key else ""
         container_args = ' --storage-container {}'.format('default') if specify_container else ""
+        msi_args = ' --storage-account-managed-identity "{}"'.format(msi) if msi else ""
+        return '--storage-account {}{}{}{}' \
+            .format(storage_account_name, key_args, container_args, msi_args)
 
+    @staticmethod
+    def _adlsgen2_arguments(storage_account_info,  specify_filesystem=True, msi = None):
+        storage_account_name = storage_account_info
+        filesystem_args = ' --storage-filesystem {}'.format('default') if specify_filesystem else ""
+        msi_args = ' --storage-account-managed-identity "{}"'.format(msi) if msi else ""
         return '--storage-account {}{}{}' \
-            .format(storage_account_name, key_args, container_args)
+            .format(storage_account_name, filesystem_args, msi_args)
 
     @staticmethod
     def _kafka_arguments():
@@ -706,7 +769,14 @@ class HDInsightClusterTests(ScenarioTest):
 
     @staticmethod
     def _component_version_arguments():
-        return '-t {} --component-version {} --version {}'.format('spark', 'spark=3.3.0', '5.1')
+        return '-t {} --component-version {} --version {}'.format('spark', 'spark=3.3', '5.1')
+
+    @staticmethod
+    def _entra_arguments(entra_user = None,entra_full_info = None):
+        if entra_user:
+            return '--entra-uid {}'.format(entra_user)
+        else :
+            return '--entra-uinfo {}'.format(entra_full_info)
 
     @staticmethod
     def _with_cluster_config():
@@ -739,15 +809,14 @@ class HDInsightClusterTests(ScenarioTest):
 
     @staticmethod
     def _with_encryption_at_host():
-        return '--workernode-size Standard_DS14_V2 --headnode-size Standard_DS14_V2 ' \
-               '--zookeepernode-size Standard_DS14_V2 --encryption-at-host true'
+        return '--workernode-size standard_ds12_v2 --headnode-size standard_ds12_v2 ' \
+               '--zookeepernode-size standard_ds12_v2 --encryption-at-host true'
 
     @staticmethod
     def _with_private_link_configurations(private_link_configuration_file):
-        return '--version 5.1 -l eastus ' \
-               '--subnet /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/ps-test/providers' \
-               '/Microsoft.Network/virtualNetworks/hdi-vn/subnets/default '\
-               '--vnet-name /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/yuchen-ps-test/providers/Microsoft.Network/virtualNetworks/hdi-vn --subnet default ' \
+        return '--version 5.1 -l eastasia ' \
+               '--subnet /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/rg/providers/Microsoft.Network/virtualNetworks/hdi-vn-0/subnets/default '\
+               '--vnet-name /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/rg/providers/Microsoft.Network/virtualNetworks/hdi-vn-0 --subnet default ' \
                '--resource-provider-connection Outbound --public-ip-tag-type FirstPartyUsage --public-ip-tag-value HDInsight --outbound-dependencies-managed-type External '\
                '--enable-private-link --private-link-configurations @"{}" '\
                .format(private_link_configuration_file)
@@ -764,3 +833,20 @@ class HDInsightClusterTests(ScenarioTest):
         return '--version 3.6 -l eastus ' \
                '--enable-compute-isolation --host-sku ESv3-Type2 ' \
                '--workernode-size Standard_E8S_V3 --headnode-size Standard_E8S_V3'
+    
+    @staticmethod
+    def wait_for_hdinsight_cluster_running(self, cluster_name=None, resource_group=None, timeout=3000, interval=60):
+        import time
+        if cluster_name is None:
+            cluster_name = self.kwargs['cluster']
+        if resource_group is None:
+            resource_group = self.kwargs['rg']
+        for _ in range(timeout // interval):
+            result = self.cmd(
+                f'az hdinsight show --name {cluster_name} --resource-group {resource_group}'
+            ).get_output_in_json()
+            state = result["properties"]["clusterState"]
+            if state == "Running":
+                return
+            time.sleep(interval)
+        raise Exception(f"Cluster {cluster_name} did not reach 'Running' state within {timeout} seconds.")
