@@ -7,8 +7,6 @@ from azure.cli.core.commands import CliCommandType
 from ._client_factory import (cf_security_tasks,
                               cf_security_alerts,
                               cf_security_alerts_suppression_rule,
-                              cf_security_settings,
-                              cf_security_contacts,
                               cf_security_auto_provisioning_settings,
                               cf_security_discovered_security_solutions,
                               cf_security_external_security_solutions,
@@ -100,18 +98,6 @@ def load_command_table(self, _):
         operation_group='security_alerts_suppression_rule'
     )
 
-    security_settings_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.security.operations#SettingsOperations.{}',
-        client_factory=cf_security_settings,
-        operation_group='security_settings'
-    )
-
-    security_contacts_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.security.operations#SecurityContactsOperations.{}',
-        client_factory=cf_security_contacts,
-        operation_group='security_contacts'
-    )
-
     security_auto_provisioning_settings_sdk = CliCommandType(
         operations_tmpl='azure.mgmt.security.operations#AutoProvisioningSettingsOperations.{}',
         client_factory=cf_security_auto_provisioning_settings,
@@ -335,21 +321,6 @@ def load_command_table(self, _):
         g.custom_show_command('show', 'get_security_alert')
         g.custom_command('update', 'update_security_alert')
 
-    with self.command_group('security setting',
-                            security_settings_sdk,
-                            client_factory=cf_security_settings) as g:
-        g.custom_command('list', 'list_security_settings')
-        g.custom_show_command('show', 'get_security_setting')
-        g.custom_command('update', 'update_security_setting')
-
-    with self.command_group('security contact',
-                            security_contacts_sdk,
-                            client_factory=cf_security_contacts) as g:
-        g.custom_command('list', 'list_security_contacts')
-        g.custom_show_command('show', 'get_security_contact')
-        g.custom_command('create', 'create_security_contact')
-        g.custom_command('delete', 'delete_security_contact')
-
     with self.command_group('security auto-provisioning-setting',
                             security_auto_provisioning_settings_sdk,
                             client_factory=cf_security_auto_provisioning_settings) as g:
