@@ -35,7 +35,7 @@ from azure.mgmt.core.tools import resource_id
 from azure.core.exceptions import HttpResponseError
 from knack.log import get_logger
 from ._utils import (
-    run_cli_cmd
+    get_resource_group
 )
 
 logger = get_logger(__name__)
@@ -946,20 +946,20 @@ def delete_security_automation(client, resource_group_name, resource_name):
     return client.delete(resource_group_name, resource_name)
 
 
-def create_or_update_security_automation(client, resource_group_name, resource_name, scopes, sources, actions, location=None, etag=None, tags=None, description=None, isEnabled=None):
+def create_or_update_security_automation(cmd, client, resource_group_name, resource_name, scopes, sources, actions, location=None, etag=None, tags=None, description=None, isEnabled=None):
 
     if location is None:
-        resourceGroup = run_cli_cmd('az group show --name {}'.format(resource_group_name))
-        location = resourceGroup['location']
+        resourceGroup = get_resource_group(cmd, resource_group_name)
+        location = resourceGroup.location
     automation = create_security_automation_object(location, scopes, sources, actions, etag, tags, description, isEnabled)
     return client.create_or_update(resource_group_name, resource_name, automation)
 
 
-def validate_security_automation(client, resource_group_name, resource_name, scopes, sources, actions, location=None, etag=None, tags=None, description=None, isEnabled=None):
+def validate_security_automation(cmd, client, resource_group_name, resource_name, scopes, sources, actions, location=None, etag=None, tags=None, description=None, isEnabled=None):
 
     if location is None:
-        resourceGroup = run_cli_cmd('az group show --name {}'.format(resource_group_name))
-        location = resourceGroup['location']
+        resourceGroup = get_resource_group(cmd, resource_group_name)
+        location = resourceGroup.location
     automation = create_security_automation_object(location, scopes, sources, actions, etag, tags, description, isEnabled)
     return client.validate(resource_group_name, resource_name, automation)
 
