@@ -62,13 +62,15 @@ class CredentialReplacer(RecordingProcessor):
 
 MASK_ID = '00000000-0000-0000-0000-000000000000'
 
-class UserMICredentialReplacer(RecordingProcessor):
+class ConfigCredentialReplacer(RecordingProcessor):
 
     def process_request(self, request):
         if is_text_payload(request) and request.body and isinstance(request.body, str):
             request.body = self._replace_ids_str(request.body)
+            request.body = self._replace_name_value_keys_str(request.body)
         elif is_text_payload(request) and request.body and isinstance(request.body, bytes):
             request.body = self._replace_ids_bytes(request.body)
+            request.body = self._replace_name_value_keys_bytes(request.body)
         
         return request
     
@@ -88,6 +90,28 @@ class UserMICredentialReplacer(RecordingProcessor):
                              r'\1"HIDDEN"', 
                              res, flags=re.IGNORECASE)
 
+        if 'vault' in res.lower() or 'rawvalue' in res.lower():
+            res = re.sub(r'("value":( ?))"[^"]*"',
+                         r'\1"HIDDEN"',
+                         res, flags=re.IGNORECASE)
+
+        return res
+    
+    def _replace_name_value_keys_bytes(self, res):
+        import re
+        sensitive_key = [b'secret', b'key', b'clientid']
+
+        for key in sensitive_key:
+            if key in res.lower():
+                res = re.sub(rb'("name":( ?)"[^"]*' + key + rb'[^"]*",( ?)"value":( ?))"[^"]*"', 
+                             rb'\1"HIDDEN"', 
+                             res, flags=re.IGNORECASE)
+
+        if b'vault' in res.lower() or b'rawvalue' in res.lower():
+            res = re.sub(rb'("value":( ?))"[^"]*"',
+                         rb'\1"HIDDEN"',
+                         res, flags=re.IGNORECASE)
+
         return res
 
     def _replace_ids_str(self, req):
