@@ -74,7 +74,7 @@ class StorageImmutabilityPolicy(ScenarioTest):
 
     @AllowLargeResponse()
     @ResourceGroupPreparer()
-    @StorageAccountPreparer(kind='StorageV2', name_prefix='clitest', location='eastus2euap')
+    @StorageAccountPreparer(kind='StorageV2', name_prefix='clitest', location='eastus2')
     def test_immutability_policy_with_allow_protected_append_writes_all(self, resource_group, storage_account):
         container_name = 'container1'
         self.cmd('storage container create --account-name {} -n {}'.format(storage_account, container_name))
