@@ -146,7 +146,7 @@ class StorageFileShareRmScenarios(StorageScenarioMixin, ScenarioTest):
         result = self.cmd('storage share-rm exists --ids {share_id_2}').get_output_in_json()
         self.assertEqual(result['exists'], False)
 
-    @ResourceGroupPreparer(name_prefix="cli", location="eastus2euap")
+    @ResourceGroupPreparer(name_prefix="cli", location="eastus2")
     def test_storage_file_using_rm_provisioned_v2_scenario(self, resource_group):
         self.kwargs = {
             'sku': 'StandardV2_LRS',
@@ -154,7 +154,7 @@ class StorageFileShareRmScenarios(StorageScenarioMixin, ScenarioTest):
             'rg': resource_group
         }
         self.cmd('az storage account create -n {sa} -g {rg} --sku {sku} --kind FileStorage '
-                 '-l eastus2euap',
+                 '-l eastus2',
                  checks=[self.check('sku.name', self.kwargs.get('sku'))])
 
         self.kwargs.update({
@@ -216,7 +216,7 @@ class StorageFileShareRmScenarios(StorageScenarioMixin, ScenarioTest):
         self.cmd('az storage share-rm list --storage-account {sa} -g {rg}',
                  checks=[self.check('length(@)', 1)])
 
-    @ResourceGroupPreparer(name_prefix="cli", location="eastus2euap")
+    @ResourceGroupPreparer(name_prefix="cli", location="eastus2")
     def test_storage_file_using_rm_provisioned_v1_scenario(self, resource_group):
         self.kwargs = {
             'sku': 'Premium_LRS',
@@ -224,7 +224,7 @@ class StorageFileShareRmScenarios(StorageScenarioMixin, ScenarioTest):
             'rg': resource_group
         }
         self.cmd('az storage account create -n {sa} -g {rg} --sku {sku} --kind FileStorage '
-                 '-l eastus2euap',
+                 '-l eastus2',
                  checks=[self.check('sku.name', self.kwargs.get('sku'))])
 
         self.kwargs.update({
@@ -261,7 +261,7 @@ class StorageFileShareRmScenarios(StorageScenarioMixin, ScenarioTest):
         self.cmd('az storage share-rm list --storage-account {sa} -g {rg}',
                  checks=[self.check('length(@)', 1)])
 
-    @ResourceGroupPreparer(name_prefix="cli_nfs", location="eastus2euap")
+    @ResourceGroupPreparer(name_prefix="cli_nfs", location="eastus2")
     @StorageAccountPreparer(name_prefix="nfs", location="eastus2", kind='FileStorage', sku='Premium_LRS')
     def test_storage_share_rm_with_NFS(self):
 
