@@ -80,7 +80,7 @@ def list_generator(pages, num_results):
 
         # handle num results
         if num_results is not None:
-            if num_results == len(result):
+            if num_results <= len(result):
                 break
 
         page = list(next(pages))
